@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\Tests\node\Kernel\Migrate\d7;
 
 use Drupal\Tests\migrate_drupal\Kernel\d7\MigrateDrupal7TestBase;
@@ -7,7 +9,7 @@ use Drupal\Tests\user\Traits\UserCreationTrait;
 use Symfony\Component\HttpFoundation\Request;
 
 /**
- * Tests node translation redirections.
+ * Tests node translation redirects.
  *
  * @group migrate_drupal
  * @group node
@@ -19,12 +21,10 @@ class NodeTranslationRedirectTest extends MigrateDrupal7TestBase {
   /**
    * {@inheritdoc}
    */
-  public static $modules = [
+  protected static $modules = [
     'content_translation',
     'language',
     'menu_ui',
-    // Required for translation migrations.
-    'migrate_drupal_multilingual',
     'node',
     'text',
     'user',
@@ -33,13 +33,12 @@ class NodeTranslationRedirectTest extends MigrateDrupal7TestBase {
   /**
    * {@inheritdoc}
    */
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
 
     $this->setUpCurrentUser();
 
     $this->installSchema('node', ['node_access']);
-    $this->installSchema('system', ['key_value']);
 
     $this->migrateUsers(FALSE);
     $this->migrateContentTypes();
@@ -55,7 +54,7 @@ class NodeTranslationRedirectTest extends MigrateDrupal7TestBase {
   /**
    * Tests that not found node translations are redirected.
    */
-  public function testNodeTranslationRedirect() {
+  public function testNodeTranslationRedirect(): void {
     $kernel = $this->container->get('http_kernel');
     $request = Request::create('/node/3');
     $response = $kernel->handle($request);
